#ifndef NT2_INCLUDE_CONSTANTS_MSIX_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MSIX_HPP_INCLUDED

#include <nt2/constant/include/constants/msix.hpp>

#endif
